@@ -11,6 +11,7 @@ void dump_args(int argc, char *argv[]);
 int do_mounts(int argc, char *argv[]);
 int mount_nfs_root(int argc, char *argv[], int flags);
 char *get_arg(int argc, char *argv[], const char *name);
+int get_flag(int argc, char *argv[], const char *name);
 int ramdisk_load(int argc, char *argv[], dev_t root_dev);
 void md_run(int argc, char *argv[]);
 
@@ -44,7 +45,7 @@ ssize_t freadfile(FILE *f, char **pptr);
         (void) (&_x == &_y);            \
         _x > _y ? _x : _y; })
 
-#undef INI_DEBUG
+#define INI_DEBUG
 
 #undef DEBUG
 #ifdef INI_DEBUG
